# pCa (PMCA) module

# Return kinetic parameters, constraints, and vector of volumes in each
# compartment (pL) (1 if gating variable, or in element corresponding to
# kappa)

# Translated from Pan 2018 cardiac AP 

import numpy as np

def kinetic_parameters(M, include_type2_reactions, dims, V):
    # Set the kinetic rate constants

    num_cols = dims['num_cols']
    num_rows = dims['num_rows']

    # constants are stored in V
    F = V['F']
    R = V['R']
    Cm = V['Cm']
    N_A = V['N_A']
    cKo = V['cKo']
    # initial concentration of enzyme pCa
    x_pCa_channel = 3*725e1 / N_A * 1e15 # unit    fmol
    E0 = x_pCa_channel/V['V_myo']

    fkc = 1e6
    smr = 1e-3
    Km = 0.5e-3 # [ =] mM
    Vmax_og = 1.15 # 0.2625 Kernick91 # 1.15 (Clancy01) # [ =] uA / uF
    Vmax = Vmax_og * Cm / (F * V['V_myo']) # [=] mM/s
    kcat = Vmax/E0 # E0 is the initial conc of enzyme pCa. [=] 1/s

    kap = fkc
    kam = kap*Km - kcat
    kbp = kcat
    kbm = kcat*smr # (kap*kbp)/kam

    k_kinetic = [kap, kbp, kam, kbm]

    # CONSTRAINTS
    N_cT = []
    K_C = []

    # volume vector
    # W = list(np.append([1] * num_cols, [V['V_myo']] * num_rows))
    W = [1] * num_cols + [V['V_myo'], V['V_o'],V['V_myo'],V['V_myo']]

    return (k_kinetic, N_cT, K_C, W)













